@@ -11,7 +11,10 @@
 # under the License.
 
 from neutron_lib.api.definitions import bgpvpn
+from neutron_lib.api.definitions import bgpvpn_routes_control
 from neutron_lib.api.definitions import data_plane_status
+from neutron_lib.api.definitions import dns
+from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import extra_dhcp_opt
 from neutron_lib.api.definitions import fip64
 from neutron_lib.api.definitions import firewall
@@ -33,7 +36,10 @@ from neutron_lib.api.definitions import trunk_details
 
 _ALL_API_DEFINITIONS = {
     bgpvpn,
+    bgpvpn_routes_control,
     data_plane_status,
+    dns,
+    dns_domain_ports,
     extra_dhcp_opt,
     fip64,
     firewall,
