@@ -80,6 +80,7 @@ KNOWN_EXTENSIONS = (
     'data-plane-status',
     'default-subnetpools',
     'dhcp_agent_scheduler',
+    'dns-domain-ports',
     'dns-integration',
     'dvr',
     'ext-gw-mode',
@@ -121,6 +122,7 @@ KNOWN_EXTENSIONS = (
     'fwaasrouterinsertion',
     'fwaas_v2',
     'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
+    'bgpvpn-routes-control',
 )
 
 KNOWN_KEYWORDS = (
